"use strict";
var amqp = require("amqplib");
var Promise = require("bluebird");
var childLogger_1 = require("./childLogger");
function isConnectionConfig(config) {
    if (config.host && config.port) {
        return true;
    }
}
var RabbitMqConnectionFactory = (function () {
    function RabbitMqConnectionFactory(logger, config) {
        this.logger = logger;
        this.connection = isConnectionConfig(config) ? "amqp://" + config.host + ":" + config.port : config;
        this.logger = childLogger_1.createChildLogger(logger, "RabbitMqConnectionFactory");
    }
    RabbitMqConnectionFactory.prototype.create = function () {
        var _this = this;
        this.logger.debug("connecting to %s", this.connection);
        return Promise.resolve(amqp.connect(this.connection)).catch(function (err) {
            _this.logger.error("failed to create connection '%s'", _this.connection);
            return Promise.reject(err);
        });
    };
    return RabbitMqConnectionFactory;
}());
exports.RabbitMqConnectionFactory = RabbitMqConnectionFactory;
var RabbitMqSingletonConnectionFactory = (function () {
    function RabbitMqSingletonConnectionFactory(logger, config) {
        this.logger = logger;
        this.connection = isConnectionConfig(config) ? "amqp://" + config.host + ":" + config.port : config;
    }
    RabbitMqSingletonConnectionFactory.prototype.create = function () {
        if (this.promise) {
            this.logger.trace("reusing connection to %s", this.connection);
            return this.promise;
        }
        this.logger.debug("creating connection to %s", this.connection);
        return this.promise = Promise.resolve(amqp.connect(this.connection));
    };
    return RabbitMqSingletonConnectionFactory;
}());
exports.RabbitMqSingletonConnectionFactory = RabbitMqSingletonConnectionFactory;
//# sourceMappingURL=connectionFactory.js.map