"use strict";
var Promise = require("bluebird");
var common_1 = require("./common");
var childLogger_1 = require("./childLogger");
var RabbitMqProducer = (function () {
    function RabbitMqProducer(logger, connectionFactory) {
        this.logger = logger;
        this.connectionFactory = connectionFactory;
        this.logger = childLogger_1.createChildLogger(logger, "RabbitMqProducer");
    }
    RabbitMqProducer.prototype.publish = function (queue, message) {
        var _this = this;
        var queueConfig = common_1.asQueueNameConfig(queue);
        var settings = this.getQueueSettings(queueConfig.dlx);
        return this.connectionFactory.create()
            .then(function (connection) { return connection.createChannel(); })
            .then(function (channel) {
            return Promise.resolve(channel.assertQueue(queueConfig.name, settings)).then(function () {
                if (!channel.sendToQueue(queueConfig.name, _this.getMessageBuffer(message), { persistent: true })) {
                    _this.logger.error("unable to send message to queue '%j' {%j}", queueConfig, message);
                    return Promise.reject(new Error("Unable to send message"));
                }
                _this.logger.trace("message sent to queue '%s' (%j)", queueConfig.name, message);
            });
        });
    };
    RabbitMqProducer.prototype.getMessageBuffer = function (message) {
        return new Buffer(JSON.stringify(message), 'utf8');
    };
    RabbitMqProducer.prototype.getQueueSettings = function (deadletterExchangeName) {
        return {
            durable: true,
            autoDelete: false,
            arguments: {
                'x-dead-letter-exchange': deadletterExchangeName
            }
        };
    };
    return RabbitMqProducer;
}());
exports.RabbitMqProducer = RabbitMqProducer;
//# sourceMappingURL=producer.js.map