"use strict";
var Promise = require("bluebird");
var common_1 = require("./common");
var childLogger_1 = require("./childLogger");
var RabbitMqPublisher = (function () {
    function RabbitMqPublisher(logger, connectionFactory) {
        this.logger = logger;
        this.connectionFactory = connectionFactory;
        this.logger = childLogger_1.createChildLogger(logger, "RabbitMqPublisher");
    }
    RabbitMqPublisher.prototype.publish = function (queue, message) {
        var _this = this;
        var queueConfig = common_1.asPubSubQueueNameConfig(queue);
        var settings = this.getSettings();
        return this.connectionFactory.create()
            .then(function (connection) { return connection.createChannel(); })
            .then(function (channel) {
            _this.logger.trace("got channel for exchange '%s'", queueConfig.dlx);
            return _this.setupChannel(channel, queueConfig)
                .then(function () {
                return Promise.resolve(channel.publish(queueConfig.dlx, '', _this.getMessageBuffer(message))).then(function () {
                    _this.logger.trace("message sent to exchange '%s' (%j)", queueConfig.dlx, message);
                });
            }).catch(function () {
                _this.logger.error("unable to send message to exchange '%j' {%j}", queueConfig.dlx, message);
                return Promise.reject(new Error("Unable to send message"));
            });
        });
    };
    RabbitMqPublisher.prototype.setupChannel = function (channel, queueConfig) {
        this.logger.trace("setup '%j'", queueConfig);
        return Promise.all(this.getChannelSetup(channel, queueConfig));
    };
    RabbitMqPublisher.prototype.getMessageBuffer = function (message) {
        return new Buffer(JSON.stringify(message), 'utf8');
    };
    RabbitMqPublisher.prototype.getChannelSetup = function (channel, queueConfig) {
        return [
            channel.assertExchange(queueConfig.dlx, 'fanout', this.getSettings()),
        ];
    };
    RabbitMqPublisher.prototype.getSettings = function () {
        return {
            durable: false,
        };
    };
    return RabbitMqPublisher;
}());
exports.RabbitMqPublisher = RabbitMqPublisher;
//# sourceMappingURL=publisher.js.map